# rmath_rohan

rmath_rohan is a Python Library for
- All basic math calculations
- Geometry formulas of Circle, Square, Rectangle, Triangle

## Installation

pip install rmath_rohan

### Example

'''python
from rmath_rohan import isadd, circle_area
print(add(5, 3))